@@ -113,8 +113,6 @@ Options::Options(int argc, char** argv, const vector<string>& specs)
 {
 }
 
-Options::~Options() = default; // Non-inline to avoid GCC -Winline warning
-
 void Options::check_name(const string& name) const
 {
     if (m_names.count(name) == 0)
@@ -145,11 +143,6 @@ string Options::get(const string& name, const string& default_value) const
     return pos->second;
 }
 
-string Options::get(const string& name, const char* default_value) const
-{
-    return get(name, string(default_value));
-}
-
 //-----------------------------------------------------------------------------
 
 } // namespace libboardgame_base
