@@ -39,8 +39,6 @@ struct Property
         LIBBOARDGAME_ASSERT(! id.empty());
         LIBBOARDGAME_ASSERT(! values.empty());
     }
-
-    ~Property();
 };
 
 //-----------------------------------------------------------------------------
@@ -67,8 +65,6 @@ public:
 
         const SgfNode* operator->() const { return m_node; }
 
-        bool is_null() const { return m_node == nullptr; }
-
     private:
         const SgfNode* m_node;
     };
@@ -85,19 +81,10 @@ public:
 
         static Iterator end() { return Iterator(nullptr); }
 
-        bool empty() const { return m_begin.is_null(); }
-
     private:
         Iterator m_begin;
     };
 
-
-    ~SgfNode();
-
-
-    /** Append a new child. */
-    void append(unique_ptr<SgfNode> node);
-
     bool has_property(const string& id) const;
 
     /** Get a property.
