@@ -6,6 +6,9 @@
 
 #include "Timer.h"
 
+#include "Assert.h"
+#include "TimeSource.h"
+
 namespace libboardgame_base {
 
 //-----------------------------------------------------------------------------
@@ -27,6 +30,6 @@ void Timer::reset(TimeSource& time_source)
     reset();
 }
 
-//----------------------------------------------------------------------------
+//-----------------------------------------------------------------------------
 
 } // namespace libboardgame_base
