@@ -18,7 +18,6 @@
 #include "Tree.h"
 #include "TreeUtil.h"
 #include "libboardgame_base/ArrayList.h"
-#include "libboardgame_base/Compiler.h"
 #include "libboardgame_base/IntervalChecker.h"
 #include "libboardgame_base/Log.h"
 #include "libboardgame_base/RandomGenerator.h"
@@ -539,7 +538,6 @@ private:
 
     bool check_abort(const ThreadState& thread_state) const;
 
-    LIBBOARDGAME_NOINLINE
     bool check_abort_expensive(ThreadState& thread_state) const;
 
     bool check_cannot_change(ThreadState& thread_state, Float remaining) const;
@@ -1248,7 +1246,8 @@ void SearchBase<S, M, R>::search_loop(ThreadState& thread_state)
         if ((check_abort(thread_state) || expensive_abort_checker())
                 && m_nu_simulations >= m_min_simulations)
             break;
-        state.start_simulation(m_nu_simulations.fetch_add(1));
+        state.start_simulation(
+            m_nu_simulations.fetch_add(1, memory_order_relaxed));
         play_in_tree(thread_state);
         if (thread_state.is_out_of_mem)
             break;
