@@ -225,10 +225,11 @@ bool AndroidUtils::checkExists(const QString& file)
 #ifdef Q_OS_ANDROID
     if (QUrl(file).isRelative())
         return QFileInfo::exists(file);
-    // Note: using ContentResolver::query() on persisted URIs without calling
-    // ACTION_OPEN_DOCUMENT first only works on some devices. Maybe try
-    // DocumentFile.exist(DocumentFile.fromSingleUri()) once we require a
-    // Qt version that supports androidx (see also QTBUG-73904).
+    // It would be easier to use DocumentFile.exists() or fromSingleUri() but
+    // adding a dependency on androidx.documentfile requires maintaining a
+    // custom build.gradle. Note that using ContentResolver::query() on
+    // persisted URIs without calling ACTION_OPEN_DOCUMENT first only works on
+    // some devices.
     auto contentResolver = getContentResolver();
     if (! contentResolver.isValid())
         return false;
@@ -279,25 +280,6 @@ QString AndroidUtils::getDisplayName([[maybe_unused]]const QString& uri)
     return {};
 }
 
-#ifdef Q_OS_ANDROID
-QString AndroidUtils::getInitialFile()
-{
-    auto intent =
-            getContext().callObjectMethod(
-                "getIntent", "()Landroid/content/Intent;");
-    if (! intent.isValid())
-        return {};
-    auto uri = intent.callObjectMethod("getData", "()Landroid/net/Uri;");
-    if (! uri.isValid())
-        return {};
-    auto uriString =
-            uri.callObjectMethod("toString", "()Ljava/lang/String;");
-    if (! uriString.isValid())
-        return {};
-    return uriString.toString();
-}
-#endif
-
 QStringList AndroidUtils::getPersistedUriPermissions()
 {
     QStringList result;
@@ -343,22 +325,12 @@ void AndroidUtils::initTheme([[maybe_unused]]QColor colorBackground)
                                 0x04000000 /* FLAG_TRANSLUCENT_STATUS */);
         auto view = window.callObjectMethod("getDecorView",
                                             "()Landroid/view/View;");
-        bool isLight = (colorBackground.lightness() > 128);
         if (QAndroidApplication::sdkVersion() < 30)
         {
             int visibility =
                     view.callMethod<int>("getSystemUiVisibility", "()I");
-            if (isLight)
-                visibility |= 0x00002000; // SYSTEM_UI_FLAG_LIGHT_STATUS_BAR
-            else
-                visibility &= ~0x00002000;
-            if (QAndroidApplication::sdkVersion() >= 26)
-            {
-                if (isLight)
-                    visibility |= 0x00000010; // SYSTEM_UI_FLAG_LIGHT_NAVIGATION_BAR
-                else
-                    visibility &= ~0x00000010;
-            }
+            visibility &= ~0x00002000; // SYSTEM_UI_FLAG_LIGHT_STATUS_BAR
+            visibility &= ~0x00000010; // SYSTEM_UI_FLAG_LIGHT_NAVIGATION_BAR
             view.callMethod<void>("setSystemUiVisibility", "(I)V", visibility);
         }
         else // QAndroidApplication::sdkVersion() >= 30
@@ -367,24 +339,16 @@ void AndroidUtils::initTheme([[maybe_unused]]QColor colorBackground)
                     view.callObjectMethod(
                         "getWindowInsetsController",
                         "()Landroid/view/WindowInsetsController;");
-            if (isLight)
-                insetsController.callMethod<void>(
-                            "setSystemBarsAppearance", "(II)V",
-                            0x00000008 // APPEARANCE_LIGHT_STATUS_BARS
-                            | 0x00000010, // APPEARANCE_LIGHT_NAVIGATION_BARS
-                            0x00000008 | 0x00000010);
-            else
-                insetsController.callMethod<void>(
-                            "setSystemBarsAppearance", "(II)V",
-                            0, 0x00000008 | 0x00000010);
+            // Clear APPEARANCE_LIGHT_STATUS_BARS and
+            // APPEARANCE_LIGHT_NAVIGATION_BARS
+            insetsController.callMethod<void>("setSystemBarsAppearance",
+                                              "(II)V", 0,
+                                              0x00000008 | 0x00000010);
         }
         window.callMethod<void>("setStatusBarColor", "(I)V",
                                 colorBackground.rgba());
-        // Set navigation bar color only if we can also use
-        // SYSTEM_UI_FLAG_LIGHT_NAVIGATION_BAR (API level 26)
-        if (QAndroidApplication::sdkVersion() >= 26)
-            window.callMethod<void>("setNavigationBarColor", "(I)V",
-                                    colorBackground.rgba());
+        window.callMethod<void>("setNavigationBarColor", "(I)V",
+                                colorBackground.rgba());
     });
 #endif
 }
