@@ -14,41 +14,20 @@ using namespace std;
 
 //-----------------------------------------------------------------------------
 
-namespace {
-
-void addHeader(QString& text)
-{
-    // Maybe explicitly setting the text and background colors can be avoided
-    // in the future to support dark mode but right now TextArea in QtQuick
-    // doesn't support dark mode anyway and with Qt 6.5/6.6, the default color
-    // scheme is broken even in light mode (white h1 text on white background,
-    // last tested on Ubuntu 23.10)
-     text.append("<head><style>"
-                 "body { background-color:white;color:black;"
-                 "       line-height:115% }"
-                 ":link { text-decoration:none;color:blue }"
-                 "</style></head><body>"_L1);
-}
-
-} //namespace
-
-//-----------------------------------------------------------------------------
-
 DocbookReader::DocbookReader(QObject* parent)
     : QObject(parent)
 {
     m_locale = QLocale::system().name();
     m_lang = m_locale.left(m_locale.indexOf("_"_L1));
-    QString fileName = ":/docbook/index_%1.docbook"_L1.arg(m_locale);
+    QString fileName = ":/help/index_%1.docbook"_L1.arg(m_locale);
     if (! QFile::exists(fileName))
     {
-        fileName = ":/docbook/index_%1.docbook"_L1.arg(m_lang);
+        fileName = ":/help/index_%1.docbook"_L1.arg(m_lang);
         if (! QFile::exists(fileName))
-            fileName = ":/docbook/index.docbook"_L1;
+            fileName = ":/help/index.docbook"_L1;
     }
     QFile file(fileName);
-    file.open(QIODevice::ReadOnly);
-    if (! m_doc.setContent(&file))
+    if (! file.open(QIODevice::ReadOnly) || ! m_doc.setContent(&file))
         return;
     m_pageIds.append("index"_L1);
     QDomElement elem = m_doc.documentElement().firstChildElement();
@@ -61,35 +40,75 @@ DocbookReader::DocbookReader(QObject* parent)
     setText();
 }
 
-QDomElement DocbookReader::findLocalized(const QDomElement& elem) const
+void DocbookReader::addHeader(QString& text) const
 {
-    QString name = elem.tagName();
-    QDomElement result = elem;
-    QDomElement e = elem;
-    while (true)
-    {
-        e = e.nextSiblingElement();
-        if (e.isNull() || e.tagName() != name)
-            break;
-        QString l = e.attribute("xml:lang"_L1);
-        if (l.isEmpty())
-            break;
-        if (l == m_locale)
-        {
-            result = e;
-            break;
-        }
-        if (l == m_lang)
-            result = e;
-    }
-    return result;
+    // Maybe explicitly setting the text/background colors can be avoided in
+    // the future but presently TextArea doesn't fully support the palette in
+    // Basic style dark mode
+    text.append("<head><style>body{background-color:");
+    text.append(m_colorBackground.name());
+    text.append(";color:");
+    text.append(m_colorText.name());
+    text.append(";line-height:115%}:link{text-decoration:none;color:");
+    text.append(m_colorLink.name());
+    text.append("}</style></head><body>"_L1);
 }
 
-QString DocbookReader::getPage(const QString& id) const
+void DocbookReader::addNavigation(QString& text)
+{
+    qsizetype prevId = -1;
+    qsizetype nextId = -1;
+    qsizetype i = m_pageIds.indexOf(m_pageId);
+    if (i >= 0)
+    {
+        prevId = i - 1;
+        nextId = i + 1;
+        if (nextId >= m_pageIds.size())
+            nextId = -1;
+    }
+    addHeader(text);
+    text.append("<p width=100% align=right>"_L1);
+    if (prevId >= 0)
+    {
+        text.append("<a href="_L1);
+        text.append(m_pageIds[prevId]);
+        text.append(">"_L1);
+        //: Go to previous page of user manual
+        text.append(tr("Previous"));
+        text.append("</a> | "_L1);
+    }
+    if (m_pageId != "index"_L1)
+    {
+        text.append("<a href=index>"_L1);
+        //: Go to table of contents of user manual
+        text.append(tr("Contents"));
+        text.append("</a> | "_L1);
+    }
+    if (nextId >= 0)
+    {
+        text.append("<a href="_L1);
+        text.append(m_pageIds[nextId]);
+        text.append(">"_L1);
+        //: Go to next page of user manual
+        text.append(tr("Next"));
+        text.append("</a> | "_L1);
+    }
+    text.append("<a href=close>"_L1);
+    text.append(tr("Close"));
+    text.append("</a></p>"_L1);
+    if (prevId >= 0)
+        m_prevPageId = m_pageIds[prevId];
+    else
+        m_prevPageId.clear();
+    if (nextId >= 0)
+        m_nextPageId = m_pageIds[nextId];
+    else
+        m_nextPageId.clear();
+}
+
+void DocbookReader::addPage(const QString& id, QString& text)
 {
     QDomElement elem = m_doc.documentElement().firstChildElement();
-    QString text;
-    addHeader(text);
     while(! elem.isNull())
     {
         if (elem.tagName() == "chapter"_L1 && elem.attribute("id"_L1) == id)
@@ -99,10 +118,9 @@ QString DocbookReader::getPage(const QString& id) const
         }
         elem = elem.nextSiblingElement();
     }
-    return text;
 }
 
-QString DocbookReader::getTableOfContents() const
+void DocbookReader::addTableOfContents(QString& text)
 {
     QString bookTitle;
     QStringList chapterTitles;
@@ -133,7 +151,6 @@ QString DocbookReader::getTableOfContents() const
         }
         elem = elem.nextSiblingElement();
     }
-    QString text;
     addHeader(text);
     text.append("<h1>"_L1);
     text.append(bookTitle);
@@ -147,7 +164,30 @@ QString DocbookReader::getTableOfContents() const
         text.append(chapterTitles[i]);
         text.append("</a><br/>"_L1);
     }
-    return text;
+}
+
+QDomElement DocbookReader::findLocalized(const QDomElement& elem) const
+{
+    QString name = elem.tagName();
+    QDomElement result = elem;
+    QDomElement e = elem;
+    while (true)
+    {
+        e = e.nextSiblingElement();
+        if (e.isNull() || e.tagName() != name)
+            break;
+        QString l = e.attribute("xml:lang"_L1);
+        if (l.isEmpty())
+            break;
+        if (l == m_locale)
+        {
+            result = e;
+            break;
+        }
+        if (l == m_lang)
+            result = e;
+    }
+    return result;
 }
 
 void DocbookReader::handleChildren(const QDomNode& node, int headerLevel,
@@ -193,7 +233,7 @@ QDomNode DocbookReader::handleNode(const QDomNode& node, int headerLevel,
     {
         text.append("<div style=\"margin-left:"_L1);
         text.append(QString::number((m_textWidth - m_imageWidth) / 2));
-        text.append("\"><img src=qrc:/docbook/"_L1);
+        text.append("\"><img src=qrc:/help/"_L1);
         text.append(elem.attribute("fileref"_L1));
         text.append(" width="_L1);
         text.append(QString::number(m_imageWidth));
@@ -245,63 +285,22 @@ QDomNode DocbookReader::handleNode(const QDomNode& node, int headerLevel,
     return node;
 }
 
-void DocbookReader::setNavigation()
+void DocbookReader::setColorBackground(const QColor& color)
 {
-    qsizetype prevId = -1;
-    qsizetype nextId = -1;
-    qsizetype i = m_pageIds.indexOf(m_pageId);
-    if (i >= 0)
-    {
-        prevId = i - 1;
-        nextId = i + 1;
-        if (nextId >= m_pageIds.size())
-            nextId = -1;
-    }
-    QString text;
-    addHeader(text);
-    text.append("<table width=100%><tr><td width=34%>"_L1);
-    if (prevId >= 0)
-    {
-        text.append("<a href="_L1);
-        text.append(m_pageIds[prevId]);
-        text.append(">"_L1);
-        //: Go to previous page of user manual
-        text.append(tr("Previous"));
-        text.append("</a>"_L1);
-    }
-    else
-        text.append("&#160;"_L1);
-    text.append("</td><td width=32% align=center>"_L1);
-    if (m_pageId != "index"_L1)
-    {
-        text.append("<a href=index>"_L1);
-        //: Go to table of contents of user manual
-        text.append(tr("Contents"));
-        text.append("</a>"_L1);
-    }
-    text.append("</td><td width=34% align=right>"_L1);
-    if (nextId >= 0)
-    {
-        text.append("<a href="_L1);
-        text.append(m_pageIds[nextId]);
-        text.append(">"_L1);
-        //: Go to next page of user manual
-        text.append(tr("Next"));
-        text.append("</a>"_L1);
-    }
-    else
-        text.append("&#160;"_L1);
-    text.append("</td></tr></table>"_L1);
-    m_navigationText = text;
-    if (prevId >= 0)
-        m_prevPageId = m_pageIds[prevId];
-    else
-        m_prevPageId.clear();
-    if (nextId >= 0)
-        m_nextPageId = m_pageIds[nextId];
-    else
-        m_nextPageId.clear();
-    emit navigationTextChanged();
+    m_colorBackground = color;
+    setText();
+}
+
+void DocbookReader::setColorLink(const QColor& color)
+{
+    m_colorLink = color;
+    setText();
+}
+
+void DocbookReader::setColorText(const QColor& color)
+{
+    m_colorText = color;
+    setText();
 }
 
 void DocbookReader::setPageId(const QString& pageId)
@@ -314,12 +313,15 @@ void DocbookReader::setPageId(const QString& pageId)
 
 void DocbookReader::setText()
 {
+    m_text.clear();
+    addHeader(m_text);
+    addNavigation(m_text);
+    m_text.append("<p>"_L1);
     if (m_pageId == "index"_L1)
-        m_text = getTableOfContents();
+        addTableOfContents(m_text);
     else
-        m_text = getPage(m_pageId);
+        addPage(m_pageId, m_text);
     emit textChanged();
-    setNavigation();
 }
 
 void DocbookReader::setTextWidth(qreal textWidth)
