@@ -165,7 +165,7 @@ PieceModel* GameModel::addEmpty(const QPoint& pos)
     preparePositionChange();
     m_game.remove_setup(c, mv);
     setSetupPlayer();
-    updateProperties();
+    updateProperties(false);
     return result;
 }
 
@@ -286,40 +286,41 @@ void GameModel::clearFile()
 
 void GameModel::createPieceModels()
 {
-    createPieceModels(Color(0));
-    createPieceModels(Color(1));
-    if (m_nuColors > 2)
-        createPieceModels(Color(2));
-    else
-        m_pieceModels[Color(2)].clear();
-    if (m_nuColors > 3)
-        createPieceModels(Color(3));
-    else
-        m_pieceModels[Color(3)].clear();
+    auto variant = m_game.get_variant();
+    auto& pieceModelsCache = m_pieceModelsCache[variant];
+    if (pieceModelsCache[Color(0)].empty())
+    {
+        createPieceModelsCache(pieceModelsCache, Color(0));
+        createPieceModelsCache(pieceModelsCache, Color(1));
+        if (m_nuColors > 2)
+            createPieceModelsCache(pieceModelsCache, Color(2));
+        if (m_nuColors > 3)
+            createPieceModelsCache(pieceModelsCache, Color(3));
+    }
+    m_pieceModels = pieceModelsCache;
 }
 
-void GameModel::createPieceModels(Color c)
+void GameModel::createPieceModelsCache(
+    ColorMap<QVariantList>& pieceModelsCache, Color c)
 {
     auto& bd = getBoard();
     auto nuPieces = bd.get_nu_uniq_pieces();
-    m_pieceModels[c].clear();
-    m_pieceModels[c].reserve(nuPieces);
+    pieceModelsCache[c].reserve(nuPieces);
     for (Piece::IntType i = 0; i < nuPieces; ++i)
     {
         Piece piece(i);
         auto nuInstances = bd.get_piece_info(piece).get_nu_instances();
         for (unsigned j = 0; j < nuInstances; ++j)
         {
-            auto variant =
-                    QVariant::fromValue(new PieceModel(this, bd, piece, c));
-            m_pieceModels[c].append(variant);
+            auto var = QVariant::fromValue(new PieceModel(this, bd, piece, c));
+            pieceModelsCache[c].append(var);
         }
     }
 }
 
 QString GameModel::decode(const string& s)
 {
-    return QString::fromStdString(s);
+    return QString::fromUtf8(s);
 }
 
 void GameModel::deleteAllVar()
@@ -448,7 +449,7 @@ PieceModel* GameModel::findUnplayedPieceModel(Color c, Piece piece)
 
 QVariantList GameModel::getPieceModels(int color)
 {
-    if (color >= 0 && color <= static_cast<int>(Color::range))
+    if (color >= 0 && color < static_cast<int>(Color::range))
         return m_pieceModels[Color(static_cast<Color::IntType>(color))];
     return m_pieceModels[Color(0)];
 }
@@ -1531,7 +1532,10 @@ PieceModel* GameModel::updatePiece(Color c, Move mv,
     return nullptr;
 }
 
-void GameModel::updatePieces()
+/** Update pieces.
+    @param restoreDefaultState Restore default orientation for pieces that are
+    no longer played on the board. */
+void GameModel::updatePieces(bool restoreDefaultState)
 {
     auto& bd = getBoard();
     ColorMap<array<bool, Board::max_pieces>> isPlayed;
@@ -1594,7 +1598,8 @@ void GameModel::updatePieces()
             auto pieceModel = qvariant_cast<PieceModel*>(m_pieceModels[c][i]);
             if (! isPlayed[c][i] && pieceModel->isPlayed())
             {
-                pieceModel->setDefaultState();
+                if (restoreDefaultState)
+                    pieceModel->setDefaultState();
                 pieceModel->setIsPlayed(false);
                 pieceModel->setMoveLabel(QString());
             }
@@ -1607,13 +1612,12 @@ void GameModel::updatePositionInfo()
     auto& current = m_game.get_current();
     auto& bd = m_game.get_board();
     auto move = get_move_number(tree, current);
-    auto left = get_moves_left(tree, current);
-    auto total = move + left;
+    auto total = move + get_moves_left(tree, current);
     auto variation = get_variation_string(current);
     QString positionInfo = QString::number(move);
-    if (left > 0 || move > 0)
+    if (move > 0 || total > move)
         positionInfo.append(getMoveAnnotationAtNode(current));
-    if (left > 0)
+    if (total > move)
     {
         positionInfo.append('/');
         positionInfo.append(QString::number(total));
@@ -1625,7 +1629,7 @@ void GameModel::updatePositionInfo()
         positionInfo.append(')');
     }
     auto positionInfoShort = positionInfo;
-    if (positionInfo.isEmpty())
+    if (positionInfo == QString::number(0))
     {
         positionInfo = bd.has_setup() ? tr("(Setup)") : tr("(No moves)");
         positionInfoShort = bd.has_setup() ? tr("(Setup)") : QString();
@@ -1648,8 +1652,10 @@ void GameModel::updatePositionInfo()
 }
 
 /** Update all properties that might change when changing the current
-    position in the game tree. */
-void GameModel::updateProperties()
+    position in the game tree.
+    @param restoreDefaultState Restore default orientation for pieces that are
+    no longer played on the board. */
+void GameModel::updateProperties(bool restoreDefaultState)
 {
     auto& bd = getBoard();
     auto& geo = bd.get_geometry();
@@ -1768,7 +1774,7 @@ void GameModel::updateProperties()
         &GameModel::isBoardEmptyChanged);
     set(m_isGameOver, isGameOver, &GameModel::isGameOverChanged);
     updateIsModified();
-    updatePieces();
+    updatePieces(restoreDefaultState);
     set(m_comment, decode(m_game.get_comment()), &GameModel::commentChanged);
     set(m_toPlay, m_isGameOver ? 0u : bd.get_effective_to_play().to_int(),
         &GameModel::toPlayChanged);
