@@ -51,27 +51,6 @@
         <source>Show variations</source>
         <translation>Varianten zeigen</translation>
     </message>
-    <message>
-        <source>Light</source>
-        <translation>Hell</translation>
-    </message>
-    <message>
-        <source>Dark</source>
-        <translation>Dunkel</translation>
-    </message>
-    <message>
-        <source>Colorblind light</source>
-        <translation>Farbenblind hell</translation>
-    </message>
-    <message>
-        <source>Colorblind dark</source>
-        <translation>Farbenblind dunkel</translation>
-    </message>
-    <message>
-        <source>System</source>
-        <extracomment>Name of theme using default system colors</extracomment>
-        <translation>System</translation>
-    </message>
     <message>
         <source>Move marking:</source>
         <translation>Zugmarkierung:</translation>
@@ -112,15 +91,15 @@
         <extracomment>Show-comment mode</extracomment>
         <translation>Nie</translation>
     </message>
-    <message>
-        <source>Color theme:</source>
-        <translation>Farbthema:</translation>
-    </message>
     <message>
         <source>Move number</source>
         <extracomment>Check box in appearance dialog whether to show the move number in the status bar.</extracomment>
         <translation>Zugnummer</translation>
     </message>
+    <message>
+        <source>Colorblind mode</source>
+        <translation>Farbenblindmodus</translation>
+    </message>
 </context>
 <context>
     <name>BoardContextMenu</name>
@@ -130,12 +109,12 @@
     </message>
     <message>
         <source>Move Annotation</source>
-        <translation>Annotierung</translation>
+        <translation>Annotation</translation>
     </message>
     <message>
         <source>Move Annotation (%1)</source>
         <extracomment>The argument is the annotation symbol for the current move</extracomment>
-        <translation>Annotierung (%1)</translation>
+        <translation>Annotation (%1)</translation>
     </message>
 </context>
 <context>
@@ -187,6 +166,10 @@
         <extracomment>Go to next page of user manual</extracomment>
         <translation>Weiter</translation>
     </message>
+    <message>
+        <source>Close</source>
+        <translation>Schließen</translation>
+    </message>
 </context>
 <context>
     <name>ExportImageDialog</name>
@@ -445,11 +428,11 @@
     </message>
     <message>
         <source>Computer is thinking… (up to %1 seconds remaining)</source>
-        <translation>Computer denkt … (maximal %1 Sekunden verbleibend)</translation>
+        <translation>Computer denkt … (bis zu %1 Sekunden verbleibend)</translation>
     </message>
     <message>
         <source>Computer is thinking… (up to %1 minutes remaining)</source>
-        <translation>Computer denkt … (maximal %1 Minuten verbleibend)</translation>
+        <translation>Computer denkt … (bis zu %1 Minuten verbleibend)</translation>
     </message>
 </context>
 <context>
@@ -533,7 +516,7 @@
     </message>
     <message>
         <source>Game Info</source>
-        <translation>Spielinformation</translation>
+        <translation>Spielinformationen</translation>
     </message>
     <message>
         <source>Move Number…</source>
@@ -646,7 +629,7 @@
     </message>
     <message>
         <source>Annotation…</source>
-        <translation>Annotierung …</translation>
+        <translation>Annotation …</translation>
     </message>
     <message>
         <source>Made main variation</source>
@@ -768,7 +751,7 @@
     </message>
     <message>
         <source>No annotation</source>
-        <translation>Keine Annotierung</translation>
+        <translation>Keine Annotation</translation>
     </message>
 </context>
 <context>
@@ -790,11 +773,11 @@
     <name>PentobiToolBar</name>
     <message>
         <source>Start a new game</source>
-        <translation>Ein neues Spiel beginnen</translation>
+        <translation>Neues Spiel starten</translation>
     </message>
     <message>
         <source>Start a rated game</source>
-        <translation>Ein gewertetes Spiel beginnen</translation>
+        <translation>Gewertetes Spiel starten</translation>
     </message>
     <message>
         <source>Set the colors played by the computer</source>
@@ -814,11 +797,11 @@
     </message>
     <message>
         <source>Go ten moves backward</source>
-        <translation>Zehn Züge zurück gehen</translation>
+        <translation>Zehn Züge zurückgehen</translation>
     </message>
     <message>
         <source>Go one move backward</source>
-        <translation>Einen Zug zurück gehen</translation>
+        <translation>Einen Zug zurückgehen</translation>
     </message>
     <message>
         <source>Go one move forward</source>
@@ -1019,7 +1002,7 @@
     <message>
         <source>Loss</source>
         <extracomment>Result of rated game is a loss</extracomment>
-        <translation>Verlust</translation>
+        <translation>Niederlage</translation>
     </message>
     <message>
         <source>Tie</source>
@@ -1296,11 +1279,6 @@
         <extracomment>Description for command line option --nobook</extracomment>
         <translation>Keine Eröffnungsbibliotheken benutzen.</translation>
     </message>
-    <message>
-        <source>Use layout optimized for smartphones.</source>
-        <extracomment>Description for command line option --mobile</extracomment>
-        <translation>Für Smartphones optimiertes Layout benutzen.</translation>
-    </message>
     <message>
         <source>Do not delay fast computer moves.</source>
         <extracomment>Description for command line option --nodelay</extracomment>
@@ -1355,5 +1333,10 @@
         <source>--mobile and --desktop cannot be used both</source>
         <translation>--mobile und --desktop können nicht beide benutzt werden.</translation>
     </message>
+    <message>
+        <source>Use smartphone layout (default on small screens, also limits maximum level).</source>
+        <extracomment>Description for command line option --mobile</extracomment>
+        <translation>Smartphone-Layout benutzen (Vorgabe auf kleinen Bildschirmen, begrenzt auch maximale Spielstufe).</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
