@@ -53,27 +53,6 @@
         <source>Show variations</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Light</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Dark</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Colorblind light</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Colorblind dark</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>System</source>
-        <extracomment>Name of theme using default system colors</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Move marking:</source>
         <translation type="unfinished"></translation>
@@ -115,12 +94,12 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Color theme:</source>
+        <source>Move number</source>
+        <extracomment>Check box in appearance dialog whether to show the move number in the status bar.</extracomment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Move number</source>
-        <extracomment>Check box in appearance dialog whether to show the move number in the status bar.</extracomment>
+        <source>Colorblind mode</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -189,6 +168,10 @@
         <extracomment>Go to next page of user manual</extracomment>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Close</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ExportImageDialog</name>
@@ -1298,11 +1281,6 @@
         <extracomment>Description for command line option --nobook</extracomment>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Use layout optimized for smartphones.</source>
-        <extracomment>Description for command line option --mobile</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Do not delay fast computer moves.</source>
         <extracomment>Description for command line option --nodelay</extracomment>
@@ -1357,5 +1335,10 @@
         <source>--mobile and --desktop cannot be used both</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Use smartphone layout (default on small screens, also limits maximum level).</source>
+        <extracomment>Description for command line option --mobile</extracomment>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
