@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="es">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -196,7 +198,7 @@
     </message>
     <message>
         <source>Untitled.png</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -498,223 +500,10 @@
 </context>
 <context>
     <name>Main</name>
-    <message>
-        <source>Pentobi</source>
-        <extracomment>Window title if no file is loaded.</extracomment>
-        <translation>Pentobi</translation>
-    </message>
-    <message>
-        <source>Game analysis is only possible in main variation.</source>
-        <translation>Solo se puede analizar la partida en la variación principal.</translation>
-    </message>
-    <message>
-        <source>Autosaved game was changed by another instance of Pentobi. Overwrite?</source>
-        <translation>Existe una partida guardada automáticamente que ha sido modificada por una nueva partida de Pentobi. ¿Desea sobrescribirla?</translation>
-    </message>
-    <message>
-        <source>Your rating has increased from %1 to %2.</source>
-        <translation>Su nivel ha subido de %1 a %2.</translation>
-    </message>
-    <message>
-        <source>Your rating has decreased from %1 to %2.</source>
-        <translation>Tu nivel ha descendido de %1 a %2.</translation>
-    </message>
-    <message>
-        <source>Your rating stays at %1.</source>
-        <translation>Su nivel sigue siendo %1.</translation>
-    </message>
-    <message>
-        <source>Delete all rating information for the current game variant?</source>
-        <translation>¿Desactivar la selección de nivel para la variante de juego actual?</translation>
-    </message>
-    <message>
-        <source>Delete all variations?</source>
-        <translation>¿Eliminar todas las variaciones?</translation>
-    </message>
-    <message>
-        <source>Save failed.</source>
-        <translation>Error al guardar.</translation>
-    </message>
-    <message>
-        <source>End of tree was reached. Continue search from start of the tree?</source>
-        <translation>Se ha alcanzado el final del árbol. ¿Desea continuar la búsqueda desde el inicio del árbol?</translation>
-    </message>
-    <message>
-        <source>No comment found</source>
-        <translation>No hay comentarios</translation>
-    </message>
-    <message>
-        <source>%1 (modified)</source>
-        <extracomment>Label for modified loaded game. The argument is the file name.</extracomment>
-        <translation>%1 (modificado)</translation>
-    </message>
-    <message>
-        <source>File has been modified by another application. Reload?</source>
-        <translation>Otra aplicación ha modificado el archivo. ¿Desea volver a cargarlo?</translation>
-    </message>
-    <message>
-        <source>Keep only position?</source>
-        <translation>¿Conservar solo posición?</translation>
-    </message>
-    <message>
-        <source>Keep only subtree?</source>
-        <translation>¿Conservar solo subárbol?</translation>
-    </message>
-    <message>
-        <source>Open failed.</source>
-        <translation>Error al abrir.</translation>
-    </message>
-    <message>
-        <source>Start rated game with Purple against Pentobi level %1?</source>
-        <translation>¿Comenzar partida con selección de nivel con moradas contra Pentobi nivel %1?</translation>
-    </message>
-    <message>
-        <source>Start rated game with Green against Pentobi level %1?</source>
-        <translation>¿Comenzar partida con selección de nivel con verdes contra Pentobi nivel %1?</translation>
-    </message>
-    <message>
-        <source>Start rated game with Blue/Red against Pentobi level %1?</source>
-        <translation>¿Comenzar partida con selección de nivel con azules/rojas contra Pentobi nivel %1?</translation>
-    </message>
-    <message>
-        <source>Start rated game with Blue against Pentobi level %1?</source>
-        <translation>¿Comenzar partida con selección de nivel con azules contra Pentobi nivel %1?</translation>
-    </message>
-    <message>
-        <source>Start rated game with Orange against Pentobi level %1?</source>
-        <translation>¿Comenzar partida con selección de nivel con naranjas contra Pentobi nivel %1?</translation>
-    </message>
-    <message>
-        <source>Start rated game with Yellow/Green against Pentobi level %1?</source>
-        <translation>¿Comenzar partida con selección de nivel con amarillas/verdes contra Pentobi nivel %1?</translation>
-    </message>
-    <message>
-        <source>Start rated game with Yellow against Pentobi level %1?</source>
-        <translation>¿Comenzar partida con selección de nivel con amarillas contra Pentobi nivel %1?</translation>
-    </message>
-    <message>
-        <source>Start rated game with Red against Pentobi level %1?</source>
-        <translation>¿Comenzar la partida con rojas, después de la selección de nivel, contra Pentobi nivel %1?</translation>
-    </message>
-    <message>
-        <source>You have not yet played rated games in this game variant.</source>
-        <translation>Todavía no ha jugado ninguna partida con selección de nivel en esta variante de juego.</translation>
-    </message>
-    <message>
-        <source>Truncate this subtree?</source>
-        <translation>¿Eliminar este subárbol?</translation>
-    </message>
-    <message>
-        <source>Truncate children?</source>
-        <translation>¿Eliminar descendientes?</translation>
-    </message>
-    <message>
-        <source>Discard game?</source>
-        <translation>¿Abandonar partida?</translation>
-    </message>
-    <message>
-        <source>Pentobi %1 (level %2)</source>
-        <extracomment>Player name for game info in rated game. First argument is version of Pentobi, second argument is level.</extracomment>
-        <translation>Pentobi %1 (nivel %2)</translation>
-    </message>
-    <message>
-        <source>Human</source>
-        <extracomment>Player name for game info in rated game.</extracomment>
-        <translation>Humano</translation>
-    </message>
-    <message>
-        <source>Rated game</source>
-        <translation>Partida con selección de nivel</translation>
-    </message>
-    <message>
-        <source>File has been modified by another application. Overwrite?</source>
-        <translation>Otra aplicación ha modificado el archivo. ¿Desea sobrescribirlo?</translation>
-    </message>
-    <message>
-        <source>%1 - Pentobi</source>
-        <extracomment>Window title if file is loaded. The argument is the file name prepended with a star if the file has been modified.</extracomment>
-        <translation>%1 - Pentobi</translation>
-    </message>
     <message>
         <source>Not enough memory</source>
         <translation>Memoria insuficiente</translation>
     </message>
-    <message>
-        <source>Game analysis aborted</source>
-        <translation>Se ha anulado el análisis de la partida</translation>
-    </message>
-    <message>
-        <source>Computer move aborted</source>
-        <translation>Se ha anulado el movimiento de la máquina</translation>
-    </message>
-    <message>
-        <source>Rating information deleted</source>
-        <translation>La información sobre el nivel ha sido borrada</translation>
-    </message>
-    <message>
-        <source>Variations deleted</source>
-        <translation>Se han borrado las variaciones</translation>
-    </message>
-    <message>
-        <source>File saved</source>
-        <translation>Archivo guardado</translation>
-    </message>
-    <message>
-        <source>Saving image failed or unsupported image format</source>
-        <translation>Se ha producido un error al guardar la imagen o el formato de archivo de imagen no es compatible</translation>
-    </message>
-    <message>
-        <source>Image saved</source>
-        <translation>Se ha guardado la imagen</translation>
-    </message>
-    <message>
-        <source>Creating image failed</source>
-        <translation>Se ha producido un error al crear la imagen</translation>
-    </message>
-    <message>
-        <source>Continuing rated game</source>
-        <translation>Continuar partida con selección de nivel</translation>
-    </message>
-    <message>
-        <source>Kept only position</source>
-        <translation>Se ha conservado solo la posición</translation>
-    </message>
-    <message>
-        <source>Kept only subtree</source>
-        <translation>Se ha conservado solo el subárbol</translation>
-    </message>
-    <message>
-        <source>Variation is now %1</source>
-        <translation>La variación es ahora %1</translation>
-    </message>
-    <message>
-        <source>Children truncated</source>
-        <translation>Se han eliminado los descendientes</translation>
-    </message>
-    <message>
-        <source>Setup</source>
-        <extracomment>Small-screen label for setup mode (short for &quot;Setup Mode&quot;).</extracomment>
-        <translation>Configuración</translation>
-    </message>
-    <message>
-        <source>Setup Mode</source>
-        <translation>Modo configuración</translation>
-    </message>
-    <message>
-        <source>Rated</source>
-        <extracomment>Label for ongoing rated game</extracomment>
-        <translation>Nivel</translation>
-    </message>
-    <message>
-        <source>Rated %1</source>
-        <extracomment>Small-screen label for finished rated game (short for &quot;Rated Game&quot;). The argument is the game number.</extracomment>
-        <translation>Nivel %1</translation>
-    </message>
-    <message>
-        <source>Rated Game %1</source>
-        <extracomment>Label for rated game. The argument is the game number.</extracomment>
-        <translation>Partida con selección de nivel %1</translation>
-    </message>
     <message>
         <source>Main Variation</source>
         <translation>Variación principal</translation>
@@ -797,50 +586,10 @@
         <source>Undo Move</source>
         <translation>Deshacer movimiento</translation>
     </message>
-    <message>
-        <source>Blue/Red</source>
-        <translation>Azul/rojo</translation>
-    </message>
-    <message>
-        <source>Purple</source>
-        <translation>Morado</translation>
-    </message>
-    <message>
-        <source>Green</source>
-        <translation>Verde</translation>
-    </message>
-    <message>
-        <source>Blue</source>
-        <translation>Azul</translation>
-    </message>
-    <message>
-        <source>Yellow/Green</source>
-        <translation>Amarillo/Verde</translation>
-    </message>
-    <message>
-        <source>Orange</source>
-        <translation>Naranja</translation>
-    </message>
-    <message>
-        <source>Yellow</source>
-        <translation>Amarillo</translation>
-    </message>
-    <message>
-        <source>Red</source>
-        <translation>Rojo</translation>
-    </message>
-    <message>
-        <source>Pentobi failed to generate a move.</source>
-        <translation>Pentobi no pudo generar un movimiento.</translation>
-    </message>
     <message>
         <source>Press back again to exit</source>
         <translation>Vuelva a presionar atrás para salir</translation>
     </message>
-    <message>
-        <source>Untitled.blksgf</source>
-        <translation type="unfinished"/>
-    </message>
 </context>
 <context>
     <name>MenuComputer</name>
@@ -1282,6 +1031,259 @@
 </context>
 <context>
     <name>main</name>
+    <message>
+        <source>Pentobi</source>
+        <extracomment>Window title if no file is loaded.</extracomment>
+        <translation>Pentobi</translation>
+    </message>
+    <message>
+        <source>Game analysis is only possible in main variation.</source>
+        <translation>Solo se puede analizar la partida en la variación principal.</translation>
+    </message>
+    <message>
+        <source>Autosaved game was changed by another instance of Pentobi. Overwrite?</source>
+        <translation>Existe una partida guardada automáticamente que ha sido modificada por una nueva partida de Pentobi. ¿Desea sobrescribirla?</translation>
+    </message>
+    <message>
+        <source>Your rating has increased from %1 to %2.</source>
+        <translation>Su nivel ha subido de %1 a %2.</translation>
+    </message>
+    <message>
+        <source>Your rating has decreased from %1 to %2.</source>
+        <translation>Tu nivel ha descendido de %1 a %2.</translation>
+    </message>
+    <message>
+        <source>Your rating stays at %1.</source>
+        <translation>Su nivel sigue siendo %1.</translation>
+    </message>
+    <message>
+        <source>Delete all rating information for the current game variant?</source>
+        <translation>¿Desactivar la selección de nivel para la variante de juego actual?</translation>
+    </message>
+    <message>
+        <source>Delete all variations?</source>
+        <translation>¿Eliminar todas las variaciones?</translation>
+    </message>
+    <message>
+        <source>Save failed.</source>
+        <translation>Error al guardar.</translation>
+    </message>
+    <message>
+        <source>End of tree was reached. Continue search from start of the tree?</source>
+        <translation>Se ha alcanzado el final del árbol. ¿Desea continuar la búsqueda desde el inicio del árbol?</translation>
+    </message>
+    <message>
+        <source>No comment found</source>
+        <translation>No hay comentarios</translation>
+    </message>
+    <message>
+        <source>%1 (modified)</source>
+        <extracomment>Label for modified loaded game. The argument is the file name.</extracomment>
+        <translation>%1 (modificado)</translation>
+    </message>
+    <message>
+        <source>File has been modified by another application. Reload?</source>
+        <translation>Otra aplicación ha modificado el archivo. ¿Desea volver a cargarlo?</translation>
+    </message>
+    <message>
+        <source>Keep only position?</source>
+        <translation>¿Conservar solo posición?</translation>
+    </message>
+    <message>
+        <source>Keep only subtree?</source>
+        <translation>¿Conservar solo subárbol?</translation>
+    </message>
+    <message>
+        <source>Open failed.</source>
+        <translation>Error al abrir.</translation>
+    </message>
+    <message>
+        <source>Start rated game with Purple against Pentobi level %1?</source>
+        <translation>¿Comenzar partida con selección de nivel con moradas contra Pentobi nivel %1?</translation>
+    </message>
+    <message>
+        <source>Start rated game with Green against Pentobi level %1?</source>
+        <translation>¿Comenzar partida con selección de nivel con verdes contra Pentobi nivel %1?</translation>
+    </message>
+    <message>
+        <source>Start rated game with Blue/Red against Pentobi level %1?</source>
+        <translation>¿Comenzar partida con selección de nivel con azules/rojas contra Pentobi nivel %1?</translation>
+    </message>
+    <message>
+        <source>Start rated game with Blue against Pentobi level %1?</source>
+        <translation>¿Comenzar partida con selección de nivel con azules contra Pentobi nivel %1?</translation>
+    </message>
+    <message>
+        <source>Start rated game with Orange against Pentobi level %1?</source>
+        <translation>¿Comenzar partida con selección de nivel con naranjas contra Pentobi nivel %1?</translation>
+    </message>
+    <message>
+        <source>Start rated game with Yellow/Green against Pentobi level %1?</source>
+        <translation>¿Comenzar partida con selección de nivel con amarillas/verdes contra Pentobi nivel %1?</translation>
+    </message>
+    <message>
+        <source>Start rated game with Yellow against Pentobi level %1?</source>
+        <translation>¿Comenzar partida con selección de nivel con amarillas contra Pentobi nivel %1?</translation>
+    </message>
+    <message>
+        <source>Start rated game with Red against Pentobi level %1?</source>
+        <translation>¿Comenzar la partida con rojas, después de la selección de nivel, contra Pentobi nivel %1?</translation>
+    </message>
+    <message>
+        <source>You have not yet played rated games in this game variant.</source>
+        <translation>Todavía no ha jugado ninguna partida con selección de nivel en esta variante de juego.</translation>
+    </message>
+    <message>
+        <source>Truncate this subtree?</source>
+        <translation>¿Eliminar este subárbol?</translation>
+    </message>
+    <message>
+        <source>Truncate children?</source>
+        <translation>¿Eliminar descendientes?</translation>
+    </message>
+    <message>
+        <source>Discard game?</source>
+        <translation>¿Abandonar partida?</translation>
+    </message>
+    <message>
+        <source>Pentobi %1 (level %2)</source>
+        <extracomment>Player name for game info in rated game. First argument is version of Pentobi, second argument is level.</extracomment>
+        <translation>Pentobi %1 (nivel %2)</translation>
+    </message>
+    <message>
+        <source>Human</source>
+        <extracomment>Player name for game info in rated game.</extracomment>
+        <translation>Humano</translation>
+    </message>
+    <message>
+        <source>Rated game</source>
+        <translation>Partida con selección de nivel</translation>
+    </message>
+    <message>
+        <source>File has been modified by another application. Overwrite?</source>
+        <translation>Otra aplicación ha modificado el archivo. ¿Desea sobrescribirlo?</translation>
+    </message>
+    <message>
+        <source>%1 - Pentobi</source>
+        <extracomment>Window title if file is loaded. The argument is the file name prepended with a star if the file has been modified.</extracomment>
+        <translation>%1 - Pentobi</translation>
+    </message>
+    <message>
+        <source>Game analysis aborted</source>
+        <translation>Se ha anulado el análisis de la partida</translation>
+    </message>
+    <message>
+        <source>Computer move aborted</source>
+        <translation>Se ha anulado el movimiento de la máquina</translation>
+    </message>
+    <message>
+        <source>Rating information deleted</source>
+        <translation>La información sobre el nivel ha sido borrada</translation>
+    </message>
+    <message>
+        <source>Variations deleted</source>
+        <translation>Se han borrado las variaciones</translation>
+    </message>
+    <message>
+        <source>File saved</source>
+        <translation>Archivo guardado</translation>
+    </message>
+    <message>
+        <source>Saving image failed or unsupported image format</source>
+        <translation>Se ha producido un error al guardar la imagen o el formato de archivo de imagen no es compatible</translation>
+    </message>
+    <message>
+        <source>Image saved</source>
+        <translation>Se ha guardado la imagen</translation>
+    </message>
+    <message>
+        <source>Creating image failed</source>
+        <translation>Se ha producido un error al crear la imagen</translation>
+    </message>
+    <message>
+        <source>Continuing rated game</source>
+        <translation>Continuar partida con selección de nivel</translation>
+    </message>
+    <message>
+        <source>Kept only position</source>
+        <translation>Se ha conservado solo la posición</translation>
+    </message>
+    <message>
+        <source>Kept only subtree</source>
+        <translation>Se ha conservado solo el subárbol</translation>
+    </message>
+    <message>
+        <source>Variation is now %1</source>
+        <translation>La variación es ahora %1</translation>
+    </message>
+    <message>
+        <source>Children truncated</source>
+        <translation>Se han eliminado los descendientes</translation>
+    </message>
+    <message>
+        <source>Setup</source>
+        <extracomment>Small-screen label for setup mode (short for &quot;Setup Mode&quot;).</extracomment>
+        <translation>Configuración</translation>
+    </message>
+    <message>
+        <source>Setup Mode</source>
+        <translation>Modo configuración</translation>
+    </message>
+    <message>
+        <source>Rated</source>
+        <extracomment>Label for ongoing rated game</extracomment>
+        <translation>Nivel</translation>
+    </message>
+    <message>
+        <source>Rated %1</source>
+        <extracomment>Small-screen label for finished rated game (short for &quot;Rated Game&quot;). The argument is the game number.</extracomment>
+        <translation>Nivel %1</translation>
+    </message>
+    <message>
+        <source>Rated Game %1</source>
+        <extracomment>Label for rated game. The argument is the game number.</extracomment>
+        <translation>Partida con selección de nivel %1</translation>
+    </message>
+    <message>
+        <source>Blue/Red</source>
+        <translation>Azul/rojo</translation>
+    </message>
+    <message>
+        <source>Purple</source>
+        <translation>Morado</translation>
+    </message>
+    <message>
+        <source>Green</source>
+        <translation>Verde</translation>
+    </message>
+    <message>
+        <source>Blue</source>
+        <translation>Azul</translation>
+    </message>
+    <message>
+        <source>Yellow/Green</source>
+        <translation>Amarillo/Verde</translation>
+    </message>
+    <message>
+        <source>Orange</source>
+        <translation>Naranja</translation>
+    </message>
+    <message>
+        <source>Yellow</source>
+        <translation>Amarillo</translation>
+    </message>
+    <message>
+        <source>Red</source>
+        <translation>Rojo</translation>
+    </message>
+    <message>
+        <source>Pentobi failed to generate a move.</source>
+        <translation>Pentobi no pudo generar un movimiento.</translation>
+    </message>
+    <message>
+        <source>Untitled.blksgf</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>computer opponent for the board game Blokus</source>
         <translation>rival virtual para el juego de mesa Blokus</translation>
@@ -1347,4 +1349,4 @@
         <translation>Demasiados argumentos</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
