@@ -51,27 +51,6 @@
         <source>Show variations</source>
         <translation>Afficher les variations</translation>
     </message>
-    <message>
-        <source>Light</source>
-        <translation>Clair</translation>
-    </message>
-    <message>
-        <source>Dark</source>
-        <translation>Noir</translation>
-    </message>
-    <message>
-        <source>Colorblind light</source>
-        <translation>Daltonien clair</translation>
-    </message>
-    <message>
-        <source>Colorblind dark</source>
-        <translation>Daltonien noir</translation>
-    </message>
-    <message>
-        <source>System</source>
-        <extracomment>Name of theme using default system colors</extracomment>
-        <translation>Système</translation>
-    </message>
     <message>
         <source>Move marking:</source>
         <translation>Marquage des coups :</translation>
@@ -112,15 +91,15 @@
         <extracomment>Show-comment mode</extracomment>
         <translation>Jamais</translation>
     </message>
-    <message>
-        <source>Color theme:</source>
-        <translation>Thème de couleur :</translation>
-    </message>
     <message>
         <source>Move number</source>
         <extracomment>Check box in appearance dialog whether to show the move number in the status bar.</extracomment>
         <translation>Numéro de coup</translation>
     </message>
+    <message>
+        <source>Colorblind mode</source>
+        <translation>Mode daltonien</translation>
+    </message>
 </context>
 <context>
     <name>BoardContextMenu</name>
@@ -187,6 +166,10 @@
         <extracomment>Go to next page of user manual</extracomment>
         <translation>Suivant</translation>
     </message>
+    <message>
+        <source>Close</source>
+        <translation>Fermer</translation>
+    </message>
 </context>
 <context>
     <name>ExportImageDialog</name>
@@ -1296,11 +1279,6 @@
         <extracomment>Description for command line option --nobook</extracomment>
         <translation>Ne pas utiliser de bibliothèques d&apos;ouvertures.</translation>
     </message>
-    <message>
-        <source>Use layout optimized for smartphones.</source>
-        <extracomment>Description for command line option --mobile</extracomment>
-        <translation>Utiliser une mise en page optimisée pour les smartphones.</translation>
-    </message>
     <message>
         <source>Do not delay fast computer moves.</source>
         <extracomment>Description for command line option --nodelay</extracomment>
@@ -1355,5 +1333,10 @@
         <source>--mobile and --desktop cannot be used both</source>
         <translation>--mobile et --desktop ne peuvent pas être utilisés tous les deux</translation>
     </message>
+    <message>
+        <source>Use smartphone layout (default on small screens, also limits maximum level).</source>
+        <extracomment>Description for command line option --mobile</extracomment>
+        <translation>Utiliser le format mobile (par défaut sur petit écran ; limite également le niveau maximal).</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
