@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nb_NO">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="nb_NO">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -12,7 +14,7 @@
     </message>
     <message>
         <source>Computer opponent for Blokus</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -175,17 +177,17 @@
     <message>
         <source>Previous</source>
         <extracomment>Go to previous page of user manual</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Contents</source>
         <extracomment>Go to table of contents of user manual</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Next</source>
         <extracomment>Go to next page of user manual</extracomment>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -196,7 +198,7 @@
     </message>
     <message>
         <source>Untitled.png</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -463,7 +465,7 @@
     <name>HelpWindow</name>
     <message>
         <source>Pentobi Help</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished">Pentobi-hjelp</translation>
     </message>
 </context>
 <context>
@@ -498,223 +500,10 @@
 </context>
 <context>
     <name>Main</name>
-    <message>
-        <source>Pentobi</source>
-        <extracomment>Window title if no file is loaded.</extracomment>
-        <translation>Pentobi</translation>
-    </message>
-    <message>
-        <source>Game analysis is only possible in main variation.</source>
-        <translation>Spillanalyse er kun tilgjengelig i hovedvariasjonen.</translation>
-    </message>
-    <message>
-        <source>Autosaved game was changed by another instance of Pentobi. Overwrite?</source>
-        <translation>Automatisk lagret spill ble endret av en annen kjørende utgave av Pentobi. Overskriv?</translation>
-    </message>
-    <message>
-        <source>Your rating has increased from %1 to %2.</source>
-        <translation>Din vurdering har økt fra %1 til %2.</translation>
-    </message>
-    <message>
-        <source>Your rating has decreased from %1 to %2.</source>
-        <translation>Din vurdering har sunket fra %1 til %2.</translation>
-    </message>
-    <message>
-        <source>Your rating stays at %1.</source>
-        <translation>Din vurdering forblir %1.</translation>
-    </message>
-    <message>
-        <source>Delete all rating information for the current game variant?</source>
-        <translation>Slett all vurderingsinformasjon fra nåværende spillvariant?</translation>
-    </message>
-    <message>
-        <source>Delete all variations?</source>
-        <translation>Slett alle variasjoner?</translation>
-    </message>
-    <message>
-        <source>Save failed.</source>
-        <translation>Lagring mislyktes.</translation>
-    </message>
-    <message>
-        <source>End of tree was reached. Continue search from start of the tree?</source>
-        <translation>Nådde slutten av treet. Fortsett søket fra starten av treet?</translation>
-    </message>
-    <message>
-        <source>No comment found</source>
-        <translation>Ingen kommentar funnet</translation>
-    </message>
-    <message>
-        <source>%1 (modified)</source>
-        <extracomment>Label for modified loaded game. The argument is the file name.</extracomment>
-        <translation>%1 (endret)</translation>
-    </message>
-    <message>
-        <source>File has been modified by another application. Reload?</source>
-        <translation>Filen har blitt endret av et annet program. Last inn på nytt?</translation>
-    </message>
-    <message>
-        <source>Keep only position?</source>
-        <translation>Kun behold posisjonen?</translation>
-    </message>
-    <message>
-        <source>Keep only subtree?</source>
-        <translation>Kun behold undertreet?</translation>
-    </message>
-    <message>
-        <source>Open failed.</source>
-        <translation>Åpning mislyktes.</translation>
-    </message>
-    <message>
-        <source>Start rated game with Purple against Pentobi level %1?</source>
-        <translation>Start vurdert spill med lilla mot Pentobi nivå %1?</translation>
-    </message>
-    <message>
-        <source>Start rated game with Green against Pentobi level %1?</source>
-        <translation>Start vurdert spill med grønn mot Pentobi nivå %1?</translation>
-    </message>
-    <message>
-        <source>Start rated game with Blue/Red against Pentobi level %1?</source>
-        <translation>Start vurdert spill med blå/rød mot Pentobi nivå %1?</translation>
-    </message>
-    <message>
-        <source>Start rated game with Blue against Pentobi level %1?</source>
-        <translation>Start vurdert spill med blå mot Pentobi nivå %1?</translation>
-    </message>
-    <message>
-        <source>Start rated game with Orange against Pentobi level %1?</source>
-        <translation>Start vurdert spill med oransje mot Pentobi nivå %1?</translation>
-    </message>
-    <message>
-        <source>Start rated game with Yellow/Green against Pentobi level %1?</source>
-        <translation>Start vurdert spill med gul/grønn mot Pentobi nivå %1?</translation>
-    </message>
-    <message>
-        <source>Start rated game with Yellow against Pentobi level %1?</source>
-        <translation>Start vurdert spill med gul mot Pentobi nivå %1?</translation>
-    </message>
-    <message>
-        <source>Start rated game with Red against Pentobi level %1?</source>
-        <translation>Start vurdert spill med rød mot Pentobi nivå %1?</translation>
-    </message>
-    <message>
-        <source>You have not yet played rated games in this game variant.</source>
-        <translation>Du har ikke spillt noen vurderte spill i denne varianten enda.</translation>
-    </message>
-    <message>
-        <source>Truncate this subtree?</source>
-        <translation>Forkort dette undertreet?</translation>
-    </message>
-    <message>
-        <source>Truncate children?</source>
-        <translation>Forkort underprosess?</translation>
-    </message>
-    <message>
-        <source>Discard game?</source>
-        <translation>Forkast spill?</translation>
-    </message>
-    <message>
-        <source>Pentobi %1 (level %2)</source>
-        <extracomment>Player name for game info in rated game. First argument is version of Pentobi, second argument is level.</extracomment>
-        <translation>Pentobi %1 (nivå %2)</translation>
-    </message>
-    <message>
-        <source>Human</source>
-        <extracomment>Player name for game info in rated game.</extracomment>
-        <translation>Menneske</translation>
-    </message>
-    <message>
-        <source>Rated game</source>
-        <translation>Vurdert spill</translation>
-    </message>
-    <message>
-        <source>File has been modified by another application. Overwrite?</source>
-        <translation>Filen har blitt endret av et annet program. Overskriv?</translation>
-    </message>
-    <message>
-        <source>%1 - Pentobi</source>
-        <extracomment>Window title if file is loaded. The argument is the file name prepended with a star if the file has been modified.</extracomment>
-        <translation>%1 - Pentobi</translation>
-    </message>
     <message>
         <source>Not enough memory</source>
         <translation>Ikke nok minne</translation>
     </message>
-    <message>
-        <source>Game analysis aborted</source>
-        <translation>Spillanalyse avbrutt</translation>
-    </message>
-    <message>
-        <source>Computer move aborted</source>
-        <translation>Datamaskintrekk avbrutt</translation>
-    </message>
-    <message>
-        <source>Rating information deleted</source>
-        <translation>Vurderingsinformasjon slettet</translation>
-    </message>
-    <message>
-        <source>Variations deleted</source>
-        <translation>Variasjoner slettet</translation>
-    </message>
-    <message>
-        <source>File saved</source>
-        <translation>Fil lagret</translation>
-    </message>
-    <message>
-        <source>Saving image failed or unsupported image format</source>
-        <translation>Lagring av bilde mislyktes, eller ustøttet bildeformat</translation>
-    </message>
-    <message>
-        <source>Image saved</source>
-        <translation>Bilde lagret</translation>
-    </message>
-    <message>
-        <source>Creating image failed</source>
-        <translation>Oppretting av bilde mislyktes</translation>
-    </message>
-    <message>
-        <source>Continuing rated game</source>
-        <translation>Fortsetter vurdert spill</translation>
-    </message>
-    <message>
-        <source>Kept only position</source>
-        <translation>Beholdt kun posisjonen</translation>
-    </message>
-    <message>
-        <source>Kept only subtree</source>
-        <translation>Beholdte kun undertre</translation>
-    </message>
-    <message>
-        <source>Variation is now %1</source>
-        <translation>Varianten er nå %1</translation>
-    </message>
-    <message>
-        <source>Children truncated</source>
-        <translation>Underprosess forkortet</translation>
-    </message>
-    <message>
-        <source>Setup</source>
-        <extracomment>Small-screen label for setup mode (short for &quot;Setup Mode&quot;).</extracomment>
-        <translation>Oppsett</translation>
-    </message>
-    <message>
-        <source>Setup Mode</source>
-        <translation>Oppsettsmodus</translation>
-    </message>
-    <message>
-        <source>Rated</source>
-        <extracomment>Label for ongoing rated game</extracomment>
-        <translation>Vurdert</translation>
-    </message>
-    <message>
-        <source>Rated %1</source>
-        <extracomment>Small-screen label for finished rated game (short for &quot;Rated Game&quot;). The argument is the game number.</extracomment>
-        <translation>Vurdert %1</translation>
-    </message>
-    <message>
-        <source>Rated Game %1</source>
-        <extracomment>Label for rated game. The argument is the game number.</extracomment>
-        <translation>Vurdert spill %1</translation>
-    </message>
     <message>
         <source>Main Variation</source>
         <translation>Hovedvariasjon</translation>
@@ -797,50 +586,10 @@
         <source>Undo Move</source>
         <translation>Angre trekk</translation>
     </message>
-    <message>
-        <source>Blue/Red</source>
-        <translation>Blå/rød</translation>
-    </message>
-    <message>
-        <source>Purple</source>
-        <translation>Lilla</translation>
-    </message>
-    <message>
-        <source>Green</source>
-        <translation>Grønn</translation>
-    </message>
-    <message>
-        <source>Blue</source>
-        <translation>Blå</translation>
-    </message>
-    <message>
-        <source>Yellow/Green</source>
-        <translation>Gul/grønn</translation>
-    </message>
-    <message>
-        <source>Orange</source>
-        <translation>Oransje</translation>
-    </message>
-    <message>
-        <source>Yellow</source>
-        <translation>Gul</translation>
-    </message>
-    <message>
-        <source>Red</source>
-        <translation>Rød</translation>
-    </message>
-    <message>
-        <source>Pentobi failed to generate a move.</source>
-        <translation>Pentobi klarte ikke å generere et trekk.</translation>
-    </message>
     <message>
         <source>Press back again to exit</source>
         <translation>Trykk «Tilbake» igjen for å avslutte.</translation>
     </message>
-    <message>
-        <source>Untitled.blksgf</source>
-        <translation type="unfinished"/>
-    </message>
 </context>
 <context>
     <name>MenuComputer</name>
@@ -918,7 +667,7 @@
     </message>
     <message>
         <source>Export Image…</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1036,7 +785,7 @@
     </message>
     <message>
         <source>All files</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1282,6 +1031,259 @@
 </context>
 <context>
     <name>main</name>
+    <message>
+        <source>Pentobi</source>
+        <extracomment>Window title if no file is loaded.</extracomment>
+        <translation>Pentobi</translation>
+    </message>
+    <message>
+        <source>Game analysis is only possible in main variation.</source>
+        <translation>Spillanalyse er kun tilgjengelig i hovedvariasjonen.</translation>
+    </message>
+    <message>
+        <source>Autosaved game was changed by another instance of Pentobi. Overwrite?</source>
+        <translation>Automatisk lagret spill ble endret av en annen kjørende utgave av Pentobi. Overskriv?</translation>
+    </message>
+    <message>
+        <source>Your rating has increased from %1 to %2.</source>
+        <translation>Din vurdering har økt fra %1 til %2.</translation>
+    </message>
+    <message>
+        <source>Your rating has decreased from %1 to %2.</source>
+        <translation>Din vurdering har sunket fra %1 til %2.</translation>
+    </message>
+    <message>
+        <source>Your rating stays at %1.</source>
+        <translation>Din vurdering forblir %1.</translation>
+    </message>
+    <message>
+        <source>Delete all rating information for the current game variant?</source>
+        <translation>Slett all vurderingsinformasjon fra nåværende spillvariant?</translation>
+    </message>
+    <message>
+        <source>Delete all variations?</source>
+        <translation>Slett alle variasjoner?</translation>
+    </message>
+    <message>
+        <source>Save failed.</source>
+        <translation>Lagring mislyktes.</translation>
+    </message>
+    <message>
+        <source>End of tree was reached. Continue search from start of the tree?</source>
+        <translation>Nådde slutten av treet. Fortsett søket fra starten av treet?</translation>
+    </message>
+    <message>
+        <source>No comment found</source>
+        <translation>Ingen kommentar funnet</translation>
+    </message>
+    <message>
+        <source>%1 (modified)</source>
+        <extracomment>Label for modified loaded game. The argument is the file name.</extracomment>
+        <translation>%1 (endret)</translation>
+    </message>
+    <message>
+        <source>File has been modified by another application. Reload?</source>
+        <translation>Filen har blitt endret av et annet program. Last inn på nytt?</translation>
+    </message>
+    <message>
+        <source>Keep only position?</source>
+        <translation>Kun behold posisjonen?</translation>
+    </message>
+    <message>
+        <source>Keep only subtree?</source>
+        <translation>Kun behold undertreet?</translation>
+    </message>
+    <message>
+        <source>Open failed.</source>
+        <translation>Åpning mislyktes.</translation>
+    </message>
+    <message>
+        <source>Start rated game with Purple against Pentobi level %1?</source>
+        <translation>Start vurdert spill med lilla mot Pentobi nivå %1?</translation>
+    </message>
+    <message>
+        <source>Start rated game with Green against Pentobi level %1?</source>
+        <translation>Start vurdert spill med grønn mot Pentobi nivå %1?</translation>
+    </message>
+    <message>
+        <source>Start rated game with Blue/Red against Pentobi level %1?</source>
+        <translation>Start vurdert spill med blå/rød mot Pentobi nivå %1?</translation>
+    </message>
+    <message>
+        <source>Start rated game with Blue against Pentobi level %1?</source>
+        <translation>Start vurdert spill med blå mot Pentobi nivå %1?</translation>
+    </message>
+    <message>
+        <source>Start rated game with Orange against Pentobi level %1?</source>
+        <translation>Start vurdert spill med oransje mot Pentobi nivå %1?</translation>
+    </message>
+    <message>
+        <source>Start rated game with Yellow/Green against Pentobi level %1?</source>
+        <translation>Start vurdert spill med gul/grønn mot Pentobi nivå %1?</translation>
+    </message>
+    <message>
+        <source>Start rated game with Yellow against Pentobi level %1?</source>
+        <translation>Start vurdert spill med gul mot Pentobi nivå %1?</translation>
+    </message>
+    <message>
+        <source>Start rated game with Red against Pentobi level %1?</source>
+        <translation>Start vurdert spill med rød mot Pentobi nivå %1?</translation>
+    </message>
+    <message>
+        <source>You have not yet played rated games in this game variant.</source>
+        <translation>Du har ikke spillt noen vurderte spill i denne varianten enda.</translation>
+    </message>
+    <message>
+        <source>Truncate this subtree?</source>
+        <translation>Forkort dette undertreet?</translation>
+    </message>
+    <message>
+        <source>Truncate children?</source>
+        <translation>Forkort underprosess?</translation>
+    </message>
+    <message>
+        <source>Discard game?</source>
+        <translation>Forkast spill?</translation>
+    </message>
+    <message>
+        <source>Pentobi %1 (level %2)</source>
+        <extracomment>Player name for game info in rated game. First argument is version of Pentobi, second argument is level.</extracomment>
+        <translation>Pentobi %1 (nivå %2)</translation>
+    </message>
+    <message>
+        <source>Human</source>
+        <extracomment>Player name for game info in rated game.</extracomment>
+        <translation>Menneske</translation>
+    </message>
+    <message>
+        <source>Rated game</source>
+        <translation>Vurdert spill</translation>
+    </message>
+    <message>
+        <source>File has been modified by another application. Overwrite?</source>
+        <translation>Filen har blitt endret av et annet program. Overskriv?</translation>
+    </message>
+    <message>
+        <source>%1 - Pentobi</source>
+        <extracomment>Window title if file is loaded. The argument is the file name prepended with a star if the file has been modified.</extracomment>
+        <translation>%1 - Pentobi</translation>
+    </message>
+    <message>
+        <source>Game analysis aborted</source>
+        <translation>Spillanalyse avbrutt</translation>
+    </message>
+    <message>
+        <source>Computer move aborted</source>
+        <translation>Datamaskintrekk avbrutt</translation>
+    </message>
+    <message>
+        <source>Rating information deleted</source>
+        <translation>Vurderingsinformasjon slettet</translation>
+    </message>
+    <message>
+        <source>Variations deleted</source>
+        <translation>Variasjoner slettet</translation>
+    </message>
+    <message>
+        <source>File saved</source>
+        <translation>Fil lagret</translation>
+    </message>
+    <message>
+        <source>Saving image failed or unsupported image format</source>
+        <translation>Lagring av bilde mislyktes, eller ustøttet bildeformat</translation>
+    </message>
+    <message>
+        <source>Image saved</source>
+        <translation>Bilde lagret</translation>
+    </message>
+    <message>
+        <source>Creating image failed</source>
+        <translation>Oppretting av bilde mislyktes</translation>
+    </message>
+    <message>
+        <source>Continuing rated game</source>
+        <translation>Fortsetter vurdert spill</translation>
+    </message>
+    <message>
+        <source>Kept only position</source>
+        <translation>Beholdt kun posisjonen</translation>
+    </message>
+    <message>
+        <source>Kept only subtree</source>
+        <translation>Beholdte kun undertre</translation>
+    </message>
+    <message>
+        <source>Variation is now %1</source>
+        <translation>Varianten er nå %1</translation>
+    </message>
+    <message>
+        <source>Children truncated</source>
+        <translation>Underprosess forkortet</translation>
+    </message>
+    <message>
+        <source>Setup</source>
+        <extracomment>Small-screen label for setup mode (short for &quot;Setup Mode&quot;).</extracomment>
+        <translation>Oppsett</translation>
+    </message>
+    <message>
+        <source>Setup Mode</source>
+        <translation>Oppsettsmodus</translation>
+    </message>
+    <message>
+        <source>Rated</source>
+        <extracomment>Label for ongoing rated game</extracomment>
+        <translation>Vurdert</translation>
+    </message>
+    <message>
+        <source>Rated %1</source>
+        <extracomment>Small-screen label for finished rated game (short for &quot;Rated Game&quot;). The argument is the game number.</extracomment>
+        <translation>Vurdert %1</translation>
+    </message>
+    <message>
+        <source>Rated Game %1</source>
+        <extracomment>Label for rated game. The argument is the game number.</extracomment>
+        <translation>Vurdert spill %1</translation>
+    </message>
+    <message>
+        <source>Blue/Red</source>
+        <translation>Blå/rød</translation>
+    </message>
+    <message>
+        <source>Purple</source>
+        <translation>Lilla</translation>
+    </message>
+    <message>
+        <source>Green</source>
+        <translation>Grønn</translation>
+    </message>
+    <message>
+        <source>Blue</source>
+        <translation>Blå</translation>
+    </message>
+    <message>
+        <source>Yellow/Green</source>
+        <translation>Gul/grønn</translation>
+    </message>
+    <message>
+        <source>Orange</source>
+        <translation>Oransje</translation>
+    </message>
+    <message>
+        <source>Yellow</source>
+        <translation>Gul</translation>
+    </message>
+    <message>
+        <source>Red</source>
+        <translation>Rød</translation>
+    </message>
+    <message>
+        <source>Pentobi failed to generate a move.</source>
+        <translation>Pentobi klarte ikke å generere et trekk.</translation>
+    </message>
+    <message>
+        <source>Untitled.blksgf</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>computer opponent for the board game Blokus</source>
         <translation>datamaskinsmotstander for brettspillet Blokus</translation>
@@ -1347,4 +1349,4 @@
         <translation>For mange argumenter</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
