@@ -16,14 +16,12 @@ function analyzeGame(nuSimulations) {
 
 function autoSaveNoVerify() {
     gameModel.autoSave()
-    syncSettings.setValueBool("computerPlays0", computerPlays0)
-    syncSettings.setValueBool("computerPlays1", computerPlays1)
-    syncSettings.setValueBool("computerPlays2", computerPlays2)
-    syncSettings.setValueBool("computerPlays3", computerPlays3)
-    syncSettings.setValueBool("isRated", isRated)
-    syncSettings.setValueBool("initComputerColorsOnNewGame", initComputerColorsOnNewGame)
-    syncSettings.setValueInt("level", playerModel.level)
-    syncSettings.sync()
+    settings.computerPlays0 = computerPlays0
+    settings.computerPlays1 = computerPlays1
+    settings.computerPlays2 = computerPlays2
+    settings.computerPlays3 = computerPlays3
+    settings.isRated = isRated
+    settings.initComputerColorsOnNewGame = initComputerColorsOnNewGame
     analyzeGameModel.autoSave(gameModel)
     if (visibility === Window.Windowed) {
         settings.x = x
@@ -170,17 +168,6 @@ function computerPlays(color) {
     }
 }
 
-function createTheme(themeName) {
-    var source = "Theme" + themeName + ".qml"
-    var component = Qt.createComponent(source)
-    if (component.status !== Component.Ready) {
-        console.warn(component.errorString())
-        source = isAndroid ? "ThemeDark.qml" : "ThemeSystem.qml"
-        component = Qt.createComponent(source)
-    }
-    return component.createObject(rootWindow)
-}
-
 function deleteAllVar() {
     showQuestion(qsTr("Delete all variations?"), deleteAllVarNoVerify)
 }
@@ -201,7 +188,9 @@ function expirePersistedUriPermissions() {
 
 function exportImage(fileUrl) {
     var board = gameView.getBoard()
-    var size = Qt.size(exportImageWidth, exportImageWidth * board.height / board.width)
+    var size = Qt.size(exportImageWidth,
+                       exportImageWidth * board.grabImageTarget.height
+                       / board.grabImageTarget.width)
     if (! board.grabImageTarget.grabToImage(function(result) {
         var ok
         if (isAndroid)
@@ -281,7 +270,7 @@ function getGameLabel(setupMode, isRated, file, isModified, short) {
             var pos = Math.max(file.lastIndexOf("/"), file.lastIndexOf("\\"))
             label = file.substring(pos + 1)
         }
-        label = label.replace("\.blksgf", "")
+        label = label.replace(/.blksgf$/i, "")
     }
     return (isModified ? "*" : "") + label
 }
@@ -330,32 +319,20 @@ function getWindowTitle(file, isModified) {
 }
 
 function init() {
-    // Convert theme settings used by older versions of Pentobi
-    switch (themeName) {
-    case "light": themeName = "Light"; break
-    case "dark": themeName = "dark"; break
-    case "colorblind-light": themeName = "ColorblindLight"; break
-    case "colorblind-dark": themeName = "ColorblindDark"; break
-    case "system": themeName = "System"; break
-    }
     if (gameModel.loadAutoSave()) {
-        computerPlays0 =
-                syncSettings.valueBool("computerPlays0", computerPlays0)
-        computerPlays1 =
-                syncSettings.valueBool("computerPlays1", computerPlays1)
-        computerPlays2 =
-                syncSettings.valueBool("computerPlays2", computerPlays2)
-        computerPlays3 =
-                syncSettings.valueBool("computerPlays3", computerPlays3)
-        isRated = syncSettings.valueBool("isRated", isRated)
-        initComputerColorsOnNewGame =
-                syncSettings.valueBool("initComputerColorsOnNewGame",
-                                       initComputerColorsOnNewGame)
+        computerPlays0 = settings.computerPlays0
+        computerPlays1 = settings.computerPlays1
+        computerPlays2 = settings.computerPlays2
+        computerPlays3 = settings.computerPlays3
+        isRated = settings.isRated
+        initComputerColorsOnNewGame = settings.initComputerColorsOnNewGame
         analyzeGameModel.loadAutoSave(gameModel)
     }
-    if (isAndroid)
-        expirePersistedUriPermissions(initialFile, gameModel.file)
-    playerModel.level = syncSettings.valueInt("level", 1)
+    if (isAndroid) {
+        Application.styleHints.colorScheme = Qt.ColorScheme.Dark
+        androidUtils.initTheme(theme.colorBackground)
+        expirePersistedUriPermissions()
+    }
     if (isMultiColor()) {
         computerPlays2 = computerPlays0
         computerPlays3 = computerPlays1
@@ -415,7 +392,7 @@ function initComputerColors() {
 }
 
 function isComputerToPlay() {
-    if (gameModel.gameVariant == "classic_3" && gameModel.toPlay === 3)
+    if (gameModel.gameVariant === "classic_3" && gameModel.toPlay === 3)
         return computerPlays(gameModel.altPlayer)
     return computerPlays(gameModel.toPlay)
 }
